summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pminsertrulesystem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pminsertrulesystem.h')
-rw-r--r--kpovmodeler/pminsertrulesystem.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kpovmodeler/pminsertrulesystem.h b/kpovmodeler/pminsertrulesystem.h
index c280bcc2..0f13a099 100644
--- a/kpovmodeler/pminsertrulesystem.h
+++ b/kpovmodeler/pminsertrulesystem.h
@@ -624,7 +624,7 @@ public:
* The parser uses the third parameter for top level objects. These objects
* have to be treated as if they are inserted after the object after.
*/
- bool canInsert( const PMObject* tqparentObject, const TQString& className,
+ bool canInsert( const PMObject* parentObject, const TQString& className,
const PMObject* after, const PMObjectList* objectsBetween = 0 );
/**
@@ -634,20 +634,20 @@ public:
* The parser uses the third parameter for top level objects. These objects
* have to be treated as if they are inserted after the object after.
*
* Same as canInsert( tqparentObject, object->class( ), after, objectsBetween )
*/
- bool canInsert( const PMObject* tqparentObject, const PMObject* object,
+ bool canInsert( const PMObject* parentObject, const PMObject* object,
const PMObject* after, const PMObjectList* objectsBetween = 0 );
/**
* Returns the number of objects that can be inserted at that position
*/
- int canInsert( const PMObject* tqparentObject, const PMObjectList& list,
+ int canInsert( const PMObject* parentObject, const PMObjectList& list,
const PMObject* after );
/**
* Returns the number of objects that can be inserted at that position
*/
- int canInsert( const PMObject* tqparentObject, const TQStringList& listOfClasses,
+ int canInsert( const PMObject* parentObject, const TQStringList& listOfClasses,
const PMObject* after );
/**
* Returns a pointer to the part
@@ -634,20 +634,20 @@ public:
* have to be treated as if they are inserted after the object after.
*
- * Same as canInsert( tqparentObject, object->class( ), after, objectsBetween )
+ * Same as canInsert( parentObject, object->class( ), after, objectsBetween )
*/